@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.17 2001/12/14 00:51:44 kevinv Exp $ */
+/* $Id: gdict-defbox.c,v 1.20 2002/05/10 14:09:33 paolo Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -30,7 +30,6 @@
 #include "gdict-pref.h"
 
 #ifdef HAVE_GNOME_PRINT
-#  include <libgnomeprint/gnome-printer-profile.h>
 #  include <math.h>
 #endif /* HAVE_GNOME_PRINT */
 
@@ -264,8 +263,8 @@ gdict_defbox_clear (GDictDefbox *defbox) {
  * Finds a string of text in the current definition
  */
 
-void 
-gdict_defbox_find (GDictDefbox *defbox, gchar *text, gboolean start) {
+gboolean 
+gdict_defbox_find (GDictDefbox *defbox, const gchar *text, gboolean start) {
     GtkTextBuffer *buffer;
     GtkTextIter start_iter, end_iter, iter;
     GtkTextIter match_start, match_end;
@@ -306,11 +305,16 @@ gdict_defbox_find (GDictDefbox *defbox, gchar *text, gboolean start) {
                                gtk_text_buffer_get_mark (buffer, "selection_bound"),
                                &match_start);     
         gtk_text_buffer_create_mark (buffer, "last_search", &match_end, FALSE);
+
+	return TRUE;
     }
     else
+    {
         gtk_signal_emit (GTK_OBJECT (defbox), 
                          gdict_defbox_signals[SUBSTR_NOT_FOUND_SIGNAL]);
 
+	return FALSE;
+    }
 }
 
 /* gdict_defbox_reset
@@ -505,6 +509,12 @@ defbox_add (GDictDefbox *defbox, gchar *def) {
          
     font = gdict_pref.typefaces[TYPEFACE_HEADWORD].font;
     color = gdict_pref.typefaces[TYPEFACE_HEADWORD].color;
+
+    p = defbox->def_cmd->db_full_name;
+    len = strlen(p);
+
+    gtk_text_buffer_insert (buffer, &iter, p, len);
+
     p = def;
     len = strcspn(def, " ");
     
