@@ -452,6 +452,8 @@ main (int argc, char *argv[])
 {
 	GConfClient *client;
 	GFloppyConfig config;
+        GnomeIconData *icon_data;
+        GnomeIconTheme *icon_theme;
 	GtkWidget *fs_entry;
 	GtkWidget *type_option;
 	GtkWidget *quick_format_rb;
@@ -460,6 +462,7 @@ main (int argc, char *argv[])
 	GSList *l;
 	gchar *image;
 	gint i;
+        gint base_size;
 
 	struct poptOption gfloppy_opts[] = {
 		{"device", '\0', POPT_ARG_STRING, NULL, 0, NULL, NULL},
@@ -479,10 +482,13 @@ main (int argc, char *argv[])
 			    argc, argv, GNOME_PARAM_POPT_TABLE, gfloppy_opts,
                             GNOME_PARAM_POPT_FLAGS, 0,
                             GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
-	/* FIXME: get the right icon */
-	image = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-                                           "document-icons/i-floppy.png", TRUE, NULL);
-	gnome_window_icon_set_default_from_file (image);
+
+        icon_theme = gnome_icon_theme_new ();
+        icon_path = gnome_icon_theme_lookup_icon (icon_theme, "gnome-dev-floppy", 24.0,
+                                                              &icon_data, &base_size);
+
+        if (icon_path)
+	  gnome_window_icon_set_default_from_file (icon_path);
 	g_free (image);
 
 	init_commands ();
@@ -530,7 +536,7 @@ main (int argc, char *argv[])
 	/* Sync UI from config. We don't emit any signal here, since we emit
 	   just after this sync the "changed" signal of type_option,
 	   which emit all the other necessary signals */
-	if (!strcmp (config.default_fs, GFLOPPY_CONFIG_FS_FAT))
+	if (config.default_fs && !strcmp (config.default_fs, GFLOPPY_CONFIG_FS_FAT))
 		gtk_option_menu_set_history (GTK_OPTION_MENU (type_option), GFLOPPY_FAT);
 	else
 		gtk_option_menu_set_history (GTK_OPTION_MENU (type_option), GFLOPPY_E2FS);
